% example.m
%
% This script shows an example of how to use the simulated annealing heuristic with extrinsic regularization.
% The standard benchmark Iris Plant Database is used, from the UCI Machine Learning Repository:
%    Newman, D.J. & Hettich, S. & Blake, C.L. & Merz, C.J. (1998). 
%      UCI Repository of machine learning databases [http://www.ics.uci.edu/~mlearn/MLRepository.html]. 
%      Irvine, CA: University of California, Department of Information and Computer Science.
%
% In each of the three binary classification cases: suggest will hold the suggested cost and gamma parameters,
%                                                   best_acc will hold the cross-validation accuracy with these parameters,
%                                               and best_sv will hold the number of support vectors with these parameters.
%
% Copyright (C) 2006, Matthew D. Boardman and Thomas P. Trappenberg, Dalhousie University, Nova Scotia, Canada
% 
%     This program is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 2 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License along
%     with this program; if not, write to the Free Software Foundation, Inc.,
%     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
% 



clear all; pack;    % clear any existing variables

% load training / validation data
fprintf('Loading data ...\n');
load iris;  % load training samples: z=inputs, labels are c1=class1 vs. other, c2=class2 vs. other, c3=class3 vs. other

% scale the inputs to [-1,1] with zero mean  (targets are already {-1,1} in this case)
fprintf('Scaling inputs to iid ...\n');
z = rescale (z);    % by default, rescales each input to [-1,1] with zero mean

% run the heuristic on one of the cases (case 2 is a nice, non-linear example: max achievable accuracy should be 98.67%.)
fprintf('Running parameter selection ...\n');

[ suggest best_acc best_sv ] = sa_svc ( 1, z, c2, [ -5.5:1.0:15.5 ], [ -15.5:1.0:5.5 ], 0.001, 5, 100, 1, .05, 1, .5, 1 );
title('Iris data set: \it Iris versicolour \rm vs. other (non-linear)');
