function [ z_out z_mean z_max ] = rescale( z_in, subtract_mean )
% function [ z_out z_mean z_max ] = rescale( z_in, subtract_mean )
%
% Rescale inputs so that they are in the range [-1,1] with zero mean (subtract_mean=1, default)
%   or such that they are in the range [0,1] with unspecified mean (subtract_mean=0).
%   All inputs will be rescaled independently.
%
%
% Copyright (C) 2006, Matthew D. Boardman and Thomas P. Trappenberg, Dalhousie University, Nova Scotia, Canada
% 
%     This program is free software; you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation; either version 2 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License along
%     with this program; if not, write to the Free Software Foundation, Inc.,
%     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
% 

if nargin < 2
    subtract_mean = 1;
end;

if nargin < 1
    z_out = 0;  % behave nicely

    fprintf('function [ z_out z_mean z_max ] = rescale( z_in, subtract_mean )\n\n');

    fprintf('Rescale inputs so that they are in the range [-1,1] with zero mean (subtract_mean=1, default)\n');
    fprintf('  or such that they are in the range [0,1] with unspecified mean (subtract_mean=0).\n');
    fprintf('  This second option is good for highly zero-weighted data, such as image data.\n');
    fprintf('  All inputs will be rescaled independently (i.i.d.) and\n');
    fprintf('  [ z_mean z_max ] are provided in order to unscale later if needed.\n');
        
    fprintf('Copyright (C) 2006, Matthew D. Boardman and Thomas P. Trappenberg, Dalhousie University, Nova Scotia, Canada.\n');
    fprintf('These MATLAB scripts come with ABSOLUTELY NO WARRANTY; for details, see GNU General Public License (license.txt).\n');
    fprintf('This is free software, and you are welcome to redistribute it under certain conditions; see license.txt for details.\n');
    fprintf('\n\n\n');
    
    return;
end;

% create an array the size of the input
z_out = z_in;

for i=1:size(z_in,2)    % for each input dimension

    if subtract_mean > 0
        z_mean = mean(z_out(:,i));
        z_out(:,i) = z_out(:,i)-z_mean;     % remove the mean
    end;

    z_max = max(abs(z_out(:,i)));
    z_out(:,i) = z_out(:,i)/z_max;          % scale by the absolute maximum

end;

